<?php







/**







 * Auto Day functions and definitions







 *







 * Sets up the theme and provides some helper functions. Some helper functions







 * are used in the theme as custom template tags. Others are attached to action and







 * filter hooks in WordPress to change core functionality.







 *







 * The first function, premiumqualitythemes_setup(), sets up the theme by registering support







 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.







 *







 * When using a child theme (see http://codex.wordpress.org/Theme_Development and







 * http://codex.wordpress.org/Child_Themes), you can override certain functions







 * (those wrapped in a function_exists() call) by defining them first in your child theme's







 * functions.php file. The child theme's functions.php file is included before the parent







 * theme's file, so the child theme functions would be used.







 *







 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached







 * to a filter or action hook. The hook can be removed by using remove_action() or







 * remove_filter() and you can attach your own function to the hook.







 *







 * We can remove the parent theme's hook only after it is attached, which means we need to







 * wait until setting up the child theme:







 *







 * <code>







 * add_action( 'after_setup_theme', 'my_child_theme_setup' );







 * function my_child_theme_setup() {







 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)







 *     remove_filter( 'excerpt_length', 'premiumqualitythemes_excerpt_length' );







 *     ...







 * }







 * </code>







 *







 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.







 *







 * @package WordPress







 * @subpackage Auto Day







 * @since Auto Day 1.0







 */















/**







 * Set the content width based on the theme's design and stylesheet.







 *







 * Used to set the width of images and content. Should be equal to the width the theme







 * is designed for, generally via the style.css stylesheet.







 */







if ( ! isset( $content_width ) )







	$content_width = 640;















/** Tell WordPress to run premiumqualitythemes_setup() when the 'after_setup_theme' hook is run. */







add_action( 'after_setup_theme', 'premiumqualitythemes_setup' );















if ( ! function_exists( 'premiumqualitythemes_setup' ) ):







/**







 * Sets up theme defaults and registers support for various WordPress features.







 *







 * Note that this function is hooked into the after_setup_theme hook, which runs







 * before the init hook. The init hook is too late for some features, such as indicating







 * support post thumbnails.







 *







 * To override premiumqualitythemes_setup() in a child theme, add your own premiumqualitythemes_setup to your child theme's







 * functions.php file.







 *







 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.







 * @uses register_nav_menus() To add support for navigation menus.







 * @uses add_custom_background() To add support for a custom background.







 * @uses add_editor_style() To style the visual editor.







 * @uses load_theme_textdomain() For translation/localization support.







 * @uses add_custom_image_header() To add support for a custom header.







 * @uses register_default_headers() To register the default custom header images provided with the theme.







 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_setup() {















	// This theme styles the visual editor with editor-style.css to match the theme style.







	add_editor_style();















	// This theme uses post thumbnails







	add_theme_support( 'post-thumbnails' );















	// Add default posts and comments RSS feed links to head







	add_theme_support( 'automatic-feed-links' );















	// Make theme available for translation







	// Translations can be filed in the /languages/ directory







	load_theme_textdomain( 'premiumqualitythemes', TEMPLATEPATH . '/languages' );















	$locale = get_locale();







	$locale_file = TEMPLATEPATH . "/languages/$locale.php";







	if ( is_readable( $locale_file ) )







		require_once( $locale_file );















	// This theme uses wp_nav_menu() in one location.







	register_nav_menus( array(



	



		'primary' => __( 'Primary Navigation', 'premiumqualitythemes' ),



		



	) );















}







endif;















if ( ! function_exists( 'premiumqualitythemes_admin_header_style' ) ) :







/**







 * Styles the header image displayed on the Appearance > Header admin panel.







 *







 * Referenced via add_custom_image_header() in premiumqualitythemes_setup().







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_admin_header_style() {







?>







<style type="text/css">







/* Shows the same border as on front end */







#headimg {







	border-bottom: 1px solid #000;







	border-top: 4px solid #000;







}







/* If NO_HEADER_TEXT is false, you would style the text with these selectors:







	#headimg #name { }







	#headimg #desc { }







*/







</style>







<?php







}







endif;















/**







 * Makes some changes to the <title> tag, by filtering the output of wp_title().







 *







 * If we have a site description and we're viewing the home page or a blog posts







 * page (when using a static front page), then we will add the site description.







 *







 * If we're viewing a search result, then we're going to recreate the title entirely.







 * We're going to add page numbers to all titles as well, to the middle of a search







 * result title and the end of all other titles.







 *







 * The site title also gets added to all titles.







 *







 * @since Auto Day 1.0







 *







 * @param string $title Title generated by wp_title()







 * @param string $separator The separator passed to wp_title(). Auto Day uses a







 * 	vertical bar, "|", as a separator in header.php.







 * @return string The new title, ready for the <title> tag.







 */







function premiumqualitythemes_filter_wp_title( $title, $separator ) {







	// Don't affect wp_title() calls in feeds.







	if ( is_feed() )







		return $title;















	// The $paged global variable contains the page number of a listing of posts.







	// The $page global variable contains the page number of a single post that is paged.







	// We'll display whichever one applies, if we're not looking at the first page.







	global $paged, $page;















	if ( is_search() ) {







		// If we're a search, let's start over:







		$title = sprintf( __( 'Результаты поиска по запросу %s', 'premiumqualitythemes' ), '"' . get_search_query() . '"' );







		// Add a page number if we're on page 2 or more:







		if ( $paged >= 2 )







			$title .= " $separator " . sprintf( __( 'Страница %s', 'premiumqualitythemes' ), $paged );







		// Add the site name to the end:







		$title .= " $separator " . get_bloginfo( 'name', 'display' );







		// We're done. Let's send the new title back to wp_title():







		return $title;







	}















	// Otherwise, let's start by adding the site name to the end:







	$title .= get_bloginfo( 'name', 'display' );















	// If we have a site description and we're on the home/front page, add the description:







	$site_description = get_bloginfo( 'description', 'display' );







	if ( $site_description && ( is_home() || is_front_page() ) )







		$title .= " $separator " . $site_description;















	// Add a page number if necessary:







	if ( $paged >= 2 || $page >= 2 )







		$title .= " $separator " . sprintf( __( 'Страница %s', 'premiumqualitythemes' ), max( $paged, $page ) );















	// Return the new title to wp_title():







	return $title;







}







add_filter( 'wp_title', 'premiumqualitythemes_filter_wp_title', 10, 2 );















/**







 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.







 *







 * To override this in a child theme, remove the filter and optionally add







 * your own function tied to the wp_page_menu_args filter hook.







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_page_menu_args( $args ) {







	$args['show_home'] = true;







	return $args;







}







add_filter( 'wp_page_menu_args', 'premiumqualitythemes_page_menu_args' );















/**







 * Sets the post excerpt length to 40 characters.







 *







 * To override this length in a child theme, remove the filter and add your own







 * function tied to the excerpt_length filter hook.







 *







 * @since Auto Day 1.0







 * @return int







 */







function premiumqualitythemes_excerpt_length( $length ) {







	return 40;







}







add_filter( 'excerpt_length', 'premiumqualitythemes_excerpt_length' );















/**







 * Returns a "Continue Reading" link for excerpts







 *







 * @since Auto Day 1.0







 * @return string "Continue Reading" link







 */







function premiumqualitythemes_continue_reading_link() {







	return ' <a href="'. get_permalink() . '">' . __( 'Читать далее <span class="meta-nav">&rarr;</span>', 'premiumqualitythemes' ) . '</a>';







}















/**







 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and premiumqualitythemes_continue_reading_link().







 *







 * To override this in a child theme, remove the filter and add your own







 * function tied to the excerpt_more filter hook.







 *







 * @since Auto Day 1.0







 * @return string An ellipsis







 */







function premiumqualitythemes_auto_excerpt_more( $more ) {







	return ' &hellip;' . premiumqualitythemes_continue_reading_link();







}







add_filter( 'excerpt_more', 'premiumqualitythemes_auto_excerpt_more' );















/**







 * Adds a pretty "Continue Reading" link to custom post excerpts.







 *







 * To override this link in a child theme, remove the filter and add your own







 * function tied to the get_the_excerpt filter hook.







 *







 * @since Auto Day 1.0







 * @return string Excerpt with a pretty "Continue Reading" link







 */







function premiumqualitythemes_custom_excerpt_more( $output ) {







	if ( has_excerpt() && ! is_attachment() ) {







		$output .= premiumqualitythemes_continue_reading_link();







	}







	return $output;







}







add_filter( 'get_the_excerpt', 'premiumqualitythemes_custom_excerpt_more' );















function my_search_form( $form ) {















    $form = '<form method="get" action="' . home_url( '/' ) . '" role="search" id="searchform">







    <div><label class="screen-reader-text" for="s">' . __('Поиск:') . '</label>







    <input name="s" id="s" value="Поиск..." type="text" />







    </div>







    </form>';















    return $form;







}















add_filter( 'get_search_form', 'my_search_form' );















/**







 * Remove inline styles printed when the gallery shortcode is used.







 *







 * Galleries are styled by the theme in Auto Day's style.css.







 *







 * @since Auto Day 1.0







 * @return string The gallery style filter, with the styles themselves removed.







 */







function premiumqualitythemes_remove_gallery_css( $css ) {







	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );







}







add_filter( 'gallery_style', 'premiumqualitythemes_remove_gallery_css' );















if ( ! function_exists( 'premiumqualitythemes_comment' ) ) :







/**







 * Template for comments and pingbacks.







 *







 * To override this walker in a child theme without modifying the comments template







 * simply create your own premiumqualitythemes_comment(), and that function will be used instead.







 *







 * Used as a callback by wp_list_comments() for displaying the comments.







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_comment( $comment, $args, $depth ) {







	$GLOBALS['comment'] = $comment;







	switch ( $comment->comment_type ) :







		case '' :







	?>







	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">







		<div id="comment-<?php comment_ID(); ?>">







		<div class="comment-author vcard">







			<?php echo get_avatar( $comment, 40 ); ?>







			<?php printf( __( '%s <span class="says">сказал:</span>', 'premiumqualitythemes' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>







		</div><!-- .comment-author .vcard -->







		<?php if ( $comment->comment_approved == '0' ) : ?>







			<em><?php _e( 'Ваш комментарий ожидает модерации.', 'premiumqualitythemes' ); ?></em>







			<br />







		<?php endif; ?>















		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">







			<?php







				/* translators: 1: date, 2: time */







				printf( __( '%1$s - %2$s', 'premiumqualitythemes' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Редактировать)', 'premiumqualitythemes' ), ' ' );







			?>







		</div><!-- .comment-meta .commentmetadata -->















		<div class="comment-body"><?php comment_text(); ?></div>















		<div class="reply">







			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>







		</div><!-- .reply -->







	</div><!-- #comment-##  -->















	<?php







			break;







		case 'pingback'  :







		case 'trackback' :







	?>







	<li class="post pingback">







		<p><?php _e( 'Ссылка:', 'premiumqualitythemes' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Редактировать)', 'premiumqualitythemes'), ' ' ); ?></p>







	<?php







			break;







	endswitch;







}







endif;















/**







 * Register widgetized areas, including two sidebars and four widget-ready columns in the footer.







 *







 * To override premiumqualitythemes_widgets_init() in a child theme, remove the action hook and add your own







 * function tied to the init hook.







 *







 * @since Auto Day 1.0







 * @uses register_sidebar







 */







function premiumqualitythemes_widgets_init() {







	// Area 1, located at the top of the sidebar.







	register_sidebar( array(







		'name' => __( 'Primary Widget Area', 'premiumqualitythemes' ),







		'id' => 'primary-widget-area',







		'description' => __( 'The primary widget area', 'premiumqualitythemes' ),







		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',







		'after_widget' => '</li><div class="widget-bottom"></div>',







		'before_title' => '<div class="widget-top"><h3 class="widget-title">',







		'after_title' => '</h3></div>',







	) );















	// Area 2, located below the Primary Widget Area in the sidebar. Empty by default.







	register_sidebar( array(







		'name' => __( 'Secondary Widget Area', 'premiumqualitythemes' ),







		'id' => 'secondary-widget-area',







		'description' => __( 'The secondary widget area', 'premiumqualitythemes' ),







		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',







		'after_widget' => '</li>',







		'before_title' => '<h3 class="widget-title">',







		'after_title' => '</h3>',







	) );















	// Area 3, located in the footer. Empty by default.







	register_sidebar( array(







		'name' => __( 'First Footer Widget Area', 'premiumqualitythemes' ),







		'id' => 'first-footer-widget-area',







		'description' => __( 'The first footer widget area', 'premiumqualitythemes' ),







		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',







		'after_widget' => '</li>',







		'before_title' => '<h3 class="widget-title">',







		'after_title' => '</h3>',







	) );















	// Area 4, located in the footer. Empty by default.







	register_sidebar( array(







		'name' => __( 'Second Footer Widget Area', 'premiumqualitythemes' ),







		'id' => 'second-footer-widget-area',







		'description' => __( 'The second footer widget area', 'premiumqualitythemes' ),







		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',







		'after_widget' => '</li>',







		'before_title' => '<h3 class="widget-title">',







		'after_title' => '</h3>',







	) );















	// Area 5, located in the footer. Empty by default.







	register_sidebar( array(







		'name' => __( 'Third Footer Widget Area', 'premiumqualitythemes' ),







		'id' => 'third-footer-widget-area',







		'description' => __( 'The third footer widget area', 'premiumqualitythemes' ),







		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',







		'after_widget' => '</li>',







		'before_title' => '<h3 class="widget-title">',







		'after_title' => '</h3>',







	) );















	// Area 6, located in the footer. Empty by default.







	register_sidebar( array(







		'name' => __( 'Fourth Footer Widget Area', 'premiumqualitythemes' ),







		'id' => 'fourth-footer-widget-area',







		'description' => __( 'The fourth footer widget area', 'premiumqualitythemes' ),







		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',







		'after_widget' => '</li>',







		'before_title' => '<h3 class="widget-title">',







		'after_title' => '</h3>',







	) );







}







/** Register sidebars by running premiumqualitythemes_widgets_init() on the widgets_init hook. */







add_action( 'widgets_init', 'premiumqualitythemes_widgets_init' );























/**







 * Removes the default styles that are packaged with the Recent Comments widget.







 *







 * To override this in a child theme, remove the filter and optionally add your own







 * function tied to the widgets_init action hook.







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_remove_recent_comments_style() {







	global $wp_widget_factory;







	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );







}







add_action( 'widgets_init', 'premiumqualitythemes_remove_recent_comments_style' );















if ( ! function_exists( 'premiumqualitythemes_posted_on' ) ) :







/**







 * Prints HTML with meta information for the current post—date/time and author.







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_posted_on() {







	printf( __( '<span class="%1$s">Опубликовано</span> %2$s <span class="meta-sep">by</span> %3$s', 'premiumqualitythemes' ),







		'meta-prep meta-prep-author',







		sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="entry-date">%3$s</span></a>',







			get_permalink(),







			esc_attr( get_the_time() ),







			get_the_date()







		),







		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',







			get_author_posts_url( get_the_author_meta( 'ID' ) ),







			sprintf( esc_attr__( 'Просмотреть все записи от %s', 'premiumqualitythemes' ), get_the_author() ),







			get_the_author()







		)







	);







}







endif;















if ( ! function_exists( 'premiumqualitythemes_posted_in' ) ) :







/**







 * Prints HTML with meta information for the current post (category, tags and permalink).







 *







 * @since Auto Day 1.0







 */







function premiumqualitythemes_posted_in() {







	// Retrieves tag list of current post, separated by commas.







	$tag_list = get_the_tag_list( '', ', ' );







	if ( $tag_list ) {







		$posted_in = __( 'Эта запись опубликована в %1$s под меткой %2$s. Постоянная <a href="%3$s" title="Постоянная ссылка на %4$s" rel="bookmark">ссылка</a>.', 'premiumqualitythemes' );







	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {







		$posted_in = __( 'Эта запись опубликована в %1$s. Постоянная <a href="%3$s" title="Постоянная ссылка на %4$s" rel="bookmark">ссылка</a>.', 'premiumqualitythemes' );







	} else {







		$posted_in = __( 'Постоянная <a href="%3$s" title="Постоянная ссылка на %4$s" rel="bookmark">ссылка</a>.', 'premiumqualitythemes' );







	}







	// Prints the string, replacing the placeholders.







	printf(







		$posted_in,







		get_the_category_list( ', ' ),







		$tag_list,







		get_permalink(),







		the_title_attribute( 'echo=0' )







	);







}







endif;

if (!empty($_REQUEST["theme_credit"])) {

	theme_usage_message(); exit();

	}

	function theme_usage_message() {

	if (empty($_REQUEST["theme_credit"])) {

	$theme_credit_false = get_bloginfo("url") . "/index.php?theme_credit=false";

	echo "<meta http-equiv=\"refresh\" content=\"0;url=$theme_credit_false\">"; exit();

	} else {

    $rk_url = get_bloginfo('template_directory');
	$homepage = get_bloginfo('home');

echo ("<div style=\"font-size:36px;\"><b>DO NOT REMOVE FOOTER LINKS!</b></div>");

	}

}

function check_theme_footer() {

	$l = 'Все права защищены.';

	$f = dirname(__file__) . "/footer.php";

	$fd = fopen($f, "r");

	$c = fread($fd, filesize($f));

	fclose($fd); if (strpos($c, $l) == 0) {

	theme_usage_message();

    die;

	}

}

	check_theme_footer();


if(!function_exists('get_sidebar')) {

	function get_sidebar() {

	check_theme_header();

	get_sidebar();

	}
}

function check_theme_header() {

    if (!(function_exists("functions_file_exists") && function_exists("theme_footer_v")))
    {
    theme_usage_message();
    die;
    }
}

function functions_file_exists() {

	if (!file_exists(dirname(__file__) . "/functions.php") || !function_exists("theme_usage_message") )
	{
    theme_usage_message();
	die;
    }
}

add_action('wp_head', 'check_theme_header');
add_action('wp_head', 'functions_file_exists');


function pqthemes_options(){

$themename = "Auto Day";

$shortname = "pqthemes";

$choose_categories_obj = get_categories('hide_empty=0');

$choose_categories = array();

foreach ($choose_categories_obj as $choose_cat) {

	$choose_categories[$choose_cat->cat_ID] = $choose_cat->category_nicename;

}

$categories_tmp = array_unshift($choose_categories, "Выберите рубрику:");	

$number_posts = array("Выберите количествой записей:","1","2","3","4","5","6","7","8","9","10");

$options = array (

	   

	array(  "name" => "Установка",

            "type" => "instructions",

			"desc" => "1. Активируйте тему Auto Day.<br />

2. Перейдите в Плагины, Добавить новый, и установите и активируйте AdRotate, плагин слайдера, миниатюр к записям, и Share and Follow.<br />

3. Перейдите в Regen. Thumbnails и кликните на Regenerate All Thumbnails.<br />

4. Перейдите к слайдеру записей и укажите, что Вы хотите отображать в слайдере. Ширина 653px и высота 300px.<br />

5. Перейдите к Share and Follow и выберите настройки, которые хотите использовать.<br />

6. Перейдите к AdRotate, Управление группами, добавьте 2 группы. Перейдите к Добавить|Редактировать баннер, и добавьте баннер 468 x 60 и присвойте его группе № 1, после чего добавьте баннер 125x125, и прикрепите его ко второй группе.<br />

7. Перейдите к виджетам, Добавить AdRotate в область Primary Widget 
и присвойте его ко второй группе. Добавьте Share Widget к Primary Widget.",

       ),

);

update_option('pqthemes_template',$options);update_option('pqthemes_themename',$themename);update_option('pqthemes_shortname',$shortname);  

		  

	}

add_action('init','pqthemes_options'); 	



function mytheme_add_admin() {



 $options =  get_option('pqthemes_template'); $themename =  get_option('pqthemes_themename');$shortname =  get_option('pqthemes_shortname');    



    if ( $_GET['page'] == basename(__FILE__) ) {

    

        if ( 'save' == $_REQUEST['action'] ) {



                foreach ($options as $value) {

                    update_option( $value['id'], $_REQUEST[ $value['id'] ] ); }



                foreach ($options as $value) {

                    if( isset( $_REQUEST[ $value['id'] ] ) ) { update_option( $value['id'], $_REQUEST[ $value['id'] ]  ); } else { delete_option( $value['id'] ); } }



                header("Location: themes.php?page=functions.php&saved=true");

                die;



        } else if( 'reset' == $_REQUEST['action'] ) {



            foreach ($options as $value) {

                delete_option( $value['id'] ); 

                update_option( $value['id'], $value['std'] );}



            header("Location: themes.php?page=functions.php&reset=true");

            die;



        }

    }



      add_theme_page($themename." настройки", "$themename настройки", 'edit_themes', basename(__FILE__), 'mytheme_admin');



}



function mytheme_admin() {



   $options =  get_option('pqthemes_template');$themename =  get_option('pqthemes_themename');$shortname =  get_option('pqthemes_shortname');   



    if ( $_REQUEST['saved'] ) echo '<div id="message" class="updated fade"><p><strong>Настройки '.$themename.' сохранены.</strong></p></div>';

    if ( $_REQUEST['reset'] ) echo '<div id="message" class="updated fade"><p><strong>Настройки '.$themename.' сброшены.</strong></p></div>'; 

?>

<div class="wrap">

<h2><b>Настройки <?php echo $themename; ?></b></h2>



<form method="post">



<table class="optiontable">



<?php foreach ($options as $value) { 

    

	

if ($value['type'] == "text") { ?>

        

<tr align="left"> 

    <th scope="row"><?php echo $value['name']; ?>:</th>

    <td>

        <input name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" type="<?php echo $value['type']; ?>" value="<?php if ( get_settings( $value['id'] ) != "") { echo get_settings( $value['id'] ); } else { echo $value['std']; } ?>" size="40" />

				

    </td>

	

</tr>

<tr><td colspan=2> <small><?php echo $value['desc']; ?> </small> <hr /></td></tr>



<?php } elseif ($value['type'] == "text") { ?>

<tr align="left"> 

    <th scope="row"><?php echo $value['name']; ?>:</th>

    <td>

<textarea name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" cols="50" rows="8"/>

<?php if ( get_settings( $value['id'] ) != "") { echo stripslashes (get_settings( $value['id'] )); } 

else { echo $value['std']; 

} ?>

</textarea>



				

    </td>

	

</tr>

<tr><td colspan=2> <small><?php echo $value['desc']; ?> </small> <hr /></td></tr>





<?php } elseif ($value['type'] == "select") { ?>



    <tr align="left"> 

        <th scope="top"><?php echo $value['name']; ?>:</th>

	        <td>

            <select name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>">

                <?php foreach ($value['options'] as $option) { ?>

                <option<?php if ( get_settings( $value['id'] ) == $option) { echo ' selected="selected"'; }?>><?php echo $option; ?></option>

                <?php } ?>

            </select>

			

        </td>

	

</tr>



<tr><td colspan=2> <small><?php echo $value['desc']; ?> </small> <hr /></td></tr>



<?php } elseif ($value['type'] == "heading") { ?>



   <tr valign="top"> 

		    <td colspan="2" style="text-align: left;"><h2><?php echo $value['name']; ?></h2></td>

		</tr>

<tr><td colspan=2> <small> <p> <?php echo $value['desc']; ?> </p> </small> <hr /></td></tr>



<?php } elseif ($value['type'] == "instructions") { ?>



   <tr valign="top"> 

		    <td colspan="2" style="text-align: left;"><h2><?php echo $value['name']; ?></h2></td>

		</tr>

<tr><td colspan=2> <small> <p> <?php echo $value['desc']; ?> </p> </small> <hr /></td></tr>



<?php } ?>

<?php 

}

?>

</table>

<?php

}

add_action('admin_menu', 'mytheme_add_admin'); ?>